@@ -13,7 +13,6 @@ use watchexec::{
 		Event, Tag,
 	},
 	filter::{globset::GlobsetFilterer, Filterer},
-	project::ProjectType,
 };
 
 pub async fn globset(args: &ArgMatches<'static>) -> Result<Arc<WatchexecFilterer>> {
@@ -32,38 +31,17 @@ pub async fn globset(args: &ArgMatches<'static>) -> Result<Arc<WatchexecFilterer
 			(String::from(".*.kate-swp"), None),
 			(String::from(".*.sw?"), None),
 			(String::from(".*.sw?x"), None),
-		]);
-
-		if vcs_types.contains(&ProjectType::Git) {
-			ignores.push((format!("**{s}.git{s}**", s = MAIN_SEPARATOR), None));
-		}
-
-		if vcs_types.contains(&ProjectType::Mercurial) {
-			ignores.push((format!("**{s}.hg{s}**", s = MAIN_SEPARATOR), None));
-		}
-
-		if vcs_types.contains(&ProjectType::Subversion) {
-			ignores.push((format!("**{s}.svn{s}**", s = MAIN_SEPARATOR), None));
-		}
-
-		if vcs_types.contains(&ProjectType::Bazaar) {
-			ignores.push((format!("**{s}.bzr{s}**", s = MAIN_SEPARATOR), None));
-		}
-
-		if vcs_types.contains(&ProjectType::Darcs) {
-			ignores.push((format!("**{s}_darcs{s}**", s = MAIN_SEPARATOR), None));
-		}
-
-		if vcs_types.contains(&ProjectType::Fossil) {
-			ignores.push((
+			(format!("**{s}.bzr{s}**", s = MAIN_SEPARATOR), None),
+			(format!("**{s}_darcs{s}**", s = MAIN_SEPARATOR), None),
+			(
 				format!("**{s}.fossil-settings{s}**", s = MAIN_SEPARATOR),
 				None,
-			));
-		}
-
-		if vcs_types.contains(&ProjectType::Pijul) {
-			ignores.push((format!("**{s}.pijul{s}**", s = MAIN_SEPARATOR), None));
-		}
+			),
+			(format!("**{s}.git{s}**", s = MAIN_SEPARATOR), None),
+			(format!("**{s}.hg{s}**", s = MAIN_SEPARATOR), None),
+			(format!("**{s}.pijul{s}**", s = MAIN_SEPARATOR), None),
+			(format!("**{s}.svn{s}**", s = MAIN_SEPARATOR), None),
+		]);
 	}
 
 	let filters = args
